firmware

package
v0.3.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Aug 19, 2026 License: MIT Imports: 9 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

var FirmwareBaseDir = "/lib/firmware"

Functions

This section is empty.

Types

type File

type File struct {
	SrcPath string // Absolute path on host (may be compressed)
	DstPath string // Path in initramfs (always uncompressed name)
	// contains filtered or unexported fields
}

File represents a firmware file to include in the initramfs

func Collect

func Collect(files []string) ([]File, error)

Collect gathers specific firmware files from the provided list Each entry should be a path relative to /lib/firmware/ If the uncompressed file doesn't exist, it will look for compressed variants

func (*File) Read

func (f *File) Read() ([]byte, error)

Read reads the content of a firmware file, decompressing if necessary

Jump to